@@ -25,7 +25,7 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
     sub foo
     {
-        my ( $callbacks, @params ) = &callbacks;    # If &callbacks makes the hairs 
+        my ( $callbacks, @params ) = &callbacks;    # If &callbacks makes the hairs
                                                     # on your neck standp, then use
                                                     # a cleaner alternative:
                                                     #
@@ -48,21 +48,21 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
 =head1 DESCRIPTION
 
-Use this module to enable a function or method to accept optional blocking 
-callbacks. Perhaps you would like to allow the caller to accept your function's 
-return value as is, or to intercept, change, eliminate or otherwise process that 
+Use this module to enable a function or method to accept optional blocking
+callbacks. Perhaps you would like to allow the caller to accept your function's
+return value as is, or to intercept, change, eliminate or otherwise process that
 reesult before it is finally returned.
 
-Callbacks are passed to your function at the end of its parameter list. This 
-module provides you with a means to identify and separate any callbacks from 
+Callbacks are passed to your function at the end of its parameter list. This
+module provides you with a means to identify and separate any callbacks from
 your function's arguments. It also provides dispatchers that will pass the
-return value into the callback chain and capture the result, ready to pass 
+return value into the callback chain and capture the result, ready to pass
 it back up to the caller.
 
-Callbacks work simply enough. Like any function, they accept input in C<@_> 
-and their output is returned explicitly or as the result of their terminal 
+Callbacks work simply enough. Like any function, they accept input in C<@_>
+and their output is returned explicitly or as the result of their terminal
 expression. When chaining together multiple callbacks, the dispatcher takes
-the function's return value and passes it to the first callback; the output 
+the function's return value and passes it to the first callback; the output
 from that callback is then passed to the following callback, and so on until
 their are no more callbacks to process the value. The result of the final
 callback is returned to the program ready to be returned to the caller.
@@ -86,18 +86,18 @@ chain is terminated for that value.
     our @EXPORT = 'callback';           # Maybe, maybe not. Up to you.
     our @EXPORT_OK = 'awesome';
     our @ISA = 'Exporter';
-    
+
     sub awesome {
         my ( $callbacks, @names ) = &callbacks;
         return $callbacks->transform(@names);
     }
-    
+
     1;
-    
+
     #############################
     # Meanwhile, back in main:: #
     #############################
-    
+
     # No callbacks ...
     #
     use MyModule 'awesome';
@@ -109,8 +109,8 @@ chain is terminated for that value.
     # Iain
     #
     # (Not so awesome.)
-    
-    
+
+
     # With a callback ...
     #
     use MyModule 'awesome';
@@ -124,14 +124,14 @@ chain is terminated for that value.
     # Iain, you're awesome!
     #
     # (This time with added awesome!)
-    
-    
+
+
     # With two callbacks ...
     #
     use MyModule 'awesome';
     my @team = awesome('Imran', 'Merlyn', 'Iain', callback {
         "$_, you're awesome!"
-    }                                   # Comma is optional here. 
+    }                                   # Comma is optional here.
     callback {
         my ($name) = @_;
         print "$name\n";
@@ -154,7 +154,7 @@ use Scalar::Util qw(blessed);
 use Carp qw(confess);
 use namespace::clean;
 
-our $VERSION = '2.001004';
+our $VERSION = '2.002000';
 $VERSION = eval $VERSION;
 our @ISA         = qw(Exporter);
 our @EXPORT_OK   = qw(callbacks callback);
@@ -168,7 +168,7 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 Takes a list of scalar values, strips away any trailing callbacks and returns
 a new list containing a blessed array reference (the callback chain) followed
-by any values from the original list that weren't callbacks. The typical 
+by any values from the original list that weren't callbacks. The typical
 imagined use case is in processing a function's argument list C<@_>:
 
     sub my_function
@@ -177,6 +177,12 @@ imagined use case is in processing a function's argument list C<@_>:
         ...
     }
 
+It is also possible to pass in a pre-prepared callback chain instead of 
+individual callbacks, in which case this method will return that value
+as its own callback chain, without inspecting the list for individual 
+callbacks. This behaviour is useful when forwarding callbacks onto a 
+more deeply nested call.
+
 The output list is packaged in such a way as to make parsing the argument list
 as easy as possible.
 
@@ -188,13 +194,22 @@ as easy as possible.
 sub new
 {
     my ( $class, @params ) = @_;
-
     my @callbacks;
-    while (    @params
-            && blessed( $params[-1] )
-            && $params[-1]->isa('Params::Callbacks::Callback') )
-    {
-        unshift @callbacks, pop @params;
+
+    if ( blessed( $params[-1] ) ) {
+        if ( $params[-1]->isa(__PACKAGE__) ) {
+            my $callback_chain = pop(@params);
+            return ( bless( $callback_chain, $class ), @params );
+        }
+        else {
+            while (    @params
+                    && blessed( $params[-1] )
+                    && $params[-1]->isa('Params::Callbacks::Callback') )
+            {
+                unshift @callbacks, pop(@params);
+            }
+
+        }
     }
 
     return ( bless( \@callbacks, $class ), @params );
@@ -278,7 +293,7 @@ sub smart_transform
 
 Takes a list of scalar values, strips away any trailing callbacks and returns
 a new list containing a blessed array reference (the callback chain) followed
-by any values from the original list that weren't callbacks. The typical 
+by any values from the original list that weren't callbacks. The typical
 imagined use case is in processing a function's argument list C<@_>:
 
     sub my_function
@@ -293,6 +308,12 @@ imagined use case is in processing a function's argument list C<@_>:
         ...
     }
 
+It is also possible to pass in a pre-prepared callback chain instead of 
+individual callbacks, in which case this function will return that value
+as its own callback chain, without inspecting the list for individual 
+callbacks. This behaviour is useful when forwarding callbacks onto a 
+more deeply nested call.
+
 The output list is packaged in such a way as to make parsing the argument list
 as easy as possible.
 
